# Copyright 2013 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License version 3, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

import sst.actions


class Page(object):
    """Base class for the page objects used in acceptance testing.

    Instance variables:
    title -- The title of the page.

    """

    title = None
    headings1 = []
    headings2 = []

    def __init__(self):
        super(Page, self).__init__()
        self.assert_page_is_open()

    def assert_page_is_open(self):
        """Assert that the page is open."""
        sst.actions.assert_title(self.title)
        if self.headings1:
            self.assert_headings1()
        if self.headings2:
            self.assert_headings2()

    def assert_headings1(self):
        """Assert the h1 elements of the page."""
        self._assert_elements_text('h1', self.headings1)

    def _assert_elements_text(self, tag, expected_text_list):
        get_text = lambda x: x.text
        page_elements_text = map(get_text, sst.actions.get_elements(tag=tag))
        assert expected_text_list == page_elements_text, \
            'Expected elements texts: {0}\n' \
            'Actual elements texts: {1}'.format(
                expected_text_list, page_elements_text)

    def assert_headings2(self):
        """Assert the h2 elements of the page."""
        self._assert_elements_text('h2', self.headings2)
